import type { ExtractPropTypes, PropType } from 'vue';
import type Layer from './layer.vue';
export declare const layerProps: {
    /**
     * 图层id,默认为随机uuid
     * Layer id, default is random uuid
     */
    id: {
        type: StringConstructor;
        default: () => string;
    };
    /**
     * 图层类型 Layer Type
     * @values symbol line fill circle raster fill-extrusion background heatmap
     */
    type: {
        type: PropType<"symbol" | "fill" | "circle" | "line" | "raster" | "background" | "fill-extrusion" | "heatmap">;
        default: string;
    };
    /**
     * 源数据过滤条件
     * Source data filter conditions
     */
    filter: {
        type: PropType<any[]>;
    };
    /**
     * mapbox layout object
     * @see {@link https://www.mapbox.com/mapbox-gl-style-spec/#layer-layout}
     */
    layout: {
        type: PropType<Record<string, any>>;
        default: () => {};
    };
    /**
     * mapbox paint object
     * @see {@link https://www.mapbox.com/mapbox-gl-style-spec/#layer-paint}
     */
    paint: {
        type: PropType<Record<string, any>>;
        default: () => {};
    };
    /**
     * 已创建source的id
     * The id of the created source
     */
    sourceId: StringConstructor;
    /**
     * 获取源数据的图层名称
     * Get the layer name of the source data
     */
    sourceLayer: StringConstructor;
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    maxzoom: {
        type: NumberConstructor;
        default: number;
    };
    metadata: {
        type: PropType<Record<string, any>>;
    };
    /**
     * 用来插入新图层的现有图层 ID
     * The ID of an existing layer into which to insert the new layer
     */
    beforeId: StringConstructor;
};
export type LayerProps = ExtractPropTypes<typeof layerProps>;
export type LayerInstance = InstanceType<typeof Layer>;
