import type { ExtractPropTypes, PropType } from 'vue';
import type MapPopup from './map-popup.vue';
export declare const mapPopupProps: {
    /**
     * 鼠标在地图缩放级别变化时是否自动关闭气泡弹窗
     * Whether to automatically close the bubble pop-up window when the mouse changes the map zoom level
     */
    hideOnZoom: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 鼠标在地图移动时是否自动关闭气泡弹窗
     * Whether to automatically close the bubble pop-up window when the mouse moves on the map
     */
    hideOnMove: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 点击地图时是否自动关闭气泡弹窗
     * Whether to automatically close the bubble pop-up window when clicking the map
     */
    hideOnClick: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * @values 'top', 'bottom', 'left', 'right', 'top-left', 'top-right', 'bottom-left', 'bottom-right'
     */
    anchor: {
        type: StringConstructor;
        validator(value: string): boolean;
        default: undefined;
    };
    /**
     * popup偏移量  正向为右/下
     * Popup offset, positive direction is right/bottom
     */
    offset: {
        type: PropType<number | number[]>;
        default: () => number[];
    };
    /**
     * 添加到popup dom元素上的Class
     * Class added to the popup DOM element
     */
    className: StringConstructor;
    coordinates: {
        type: PropType<number[]>;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 是否自动添加气泡指向三角形
     * Whether to automatically add bubble pointing triangle
     */
    showTip: {
        type: BooleanConstructor;
        default: boolean;
    };
    tipColor: {
        type: StringConstructor;
        default: string;
    };
};
export type MapPopupProps = ExtractPropTypes<typeof mapPopupProps>;
export declare const mapPopupEmits: {
    'update:show': (show: boolean) => boolean;
};
export type MapPopupEmits = typeof mapPopupEmits;
export type MapPopupInstance = InstanceType<typeof MapPopup>;
