import "csscolorparser-ts";
import { isNumber as r } from "../../common/functions.mjs";
const l = {
  zoom: {
    type: Number,
    default: 2
  },
  /**
   * 地图地理中心点坐标，采用经度、纬度的顺序
   * The coordinates of the geographic center point of the map, in the order of longitude and latitude
   */
  center: {
    type: Array,
    default: () => [116.38745, 39.91266],
    validator: (e) => e.length === 2 && e.every(r)
  },
  /**
   * 地图初始化时的方位角（旋转角度）
   * Azimuth (rotation angle) when the map is initialized
   */
  bearing: {
    type: Number,
    default: 0
  },
  /**
   * 地图初始化时的倾角
   * The tilt angle of the map when it is initialized
   */
  pitch: {
    type: Number,
    default: 0
  },
  /**
   * 地图初始化时的四至范围。如果设置了 bounds 将会覆盖掉 center 和 zoom 的设置
   * 其值为rectangle的西南点与东北点，例如：[[-73.9876, 40.7661], [-73.9397, 40.8002]]
   */
  /**
   * The bounds of the map when it is initialized. If bounds is set, it will override the center and zoom settings
   * Its value is the southwest and northeast points of the rectangle, for example: [[-73.9876, 40.7661], [-73.9397, 40.8002]]
   */
  bounds: {
    type: [Object, Array],
    default: void 0
  },
  /**
   * 设置之后，地图将限制在给定的最大范围内
   * When set, the map will be limited to the given maximum range.
   */
  maxBounds: {
    type: [Object, Array],
    default: void 0
  },
  /**
   * 是否开启抗锯齿模式；
   * 关闭后性能将有所提升
   */
  /**
   * Whether to enable anti-aliasing mode;
   * Performance will be improved after turning it off
   */
  antialias: {
    type: Boolean,
    default: !0
  },
  minzoom: {
    type: Number,
    default: 0
  },
  maxzoom: {
    type: Number,
    default: 22
  },
  hash: {
    type: [Boolean, String],
    default: !1
  },
  interactive: {
    type: Boolean,
    default: !0
  },
  bearingSnap: {
    type: Number,
    default: 7
  },
  pitchWithRotate: {
    type: Boolean,
    default: !0
  },
  clickTolerance: {
    type: Number,
    default: 3
  },
  attributionControl: {
    type: Boolean,
    default: !1
  },
  /**
   * 地图样式信息
   * 包括字体文件路径以及精灵图资源路径
   */
  /**
   * Map style information
   * Including font file path and sprite resource path
   */
  mapStyle: {
    type: [Object, String],
    default: () => ({
      version: 8,
      sources: {},
      layers: [],
      /**
       * 字体文件路径
       * Font file path
       */
      glyphs: "mapbox://fonts/mapbox/{fontstack}/{range}.pbf",
      /**
       * 精灵图资源路径
       * Sprite resource path
       */
      sprite: "mapbox://sprites/mapbox/bright-v8"
    })
  },
  glyphs: {
    type: String,
    default: ""
  },
  sprite: {
    type: String,
    default: ""
  },
  crs: [String, Array],
  extendProps: {
    type: Object,
    default: () => ({})
  }
}, u = {
  "update:pitch": (e) => r(e),
  "update:bearing": (e) => r(e),
  "update:center": (e) => Array.isArray(e) && e.every((a) => r(a)),
  "update:zoom": (e) => r(e),
  mousemove: ({
    pixel: e,
    coordinates: a,
    originalEvent: o
  }) => e.every((t) => r(t)) && a.every((t) => r(t)),
  click: ({
    pixel: e,
    coordinates: a,
    originalEvent: o
  }) => e.every((t) => r(t)) && a.every((t) => r(t)),
  dblclick: ({
    pixel: e,
    coordinates: a,
    originalEvent: o
  }) => e.every((t) => r(t)) && a.every((t) => r(t)),
  singleclick: ({
    pixel: e,
    coordinates: a,
    originalEvent: o
  }) => e.every((t) => r(t)) && a.every((t) => r(t)),
  mouseout: (e) => !0,
  created: (e) => !0
};
export {
  u as mapEmits,
  l as mapProps
};
