import type { ExtractPropTypes, PropType } from 'vue';
import type PolylineLayer from './polyline-layer.vue';
export declare const polylineLayerProps: {
    /**
     * @values 'butt' 'round' 'square'
     */
    lineCap: {
        type: PropType<"round" | "butt" | "square">;
        default: string;
    };
    /**
     * @values 'bevel' 'round' 'miter'
     */
    lineJoin: {
        type: PropType<"round" | "bevel" | "miter">;
        default: string;
    };
    opacity: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 颜色值
     * 支持 '#000000' 'rgb(0,0,0)' [255,0,0,1]等模式
     */
    /**
     * Color value
     * Supports modes such as '#000000' 'rgb(0,0,0)'
     */
    color: {
        type: PropType<string | number[]>;
        default: string;
    };
    /**
     * 宽度，以像素值为单位
     * Width, in pixels
     */
    width: {
        type: PropType<number | number[]>;
        default: number;
    };
    /**
     * 偏移量，正数表示 右/下
     * Offset, positive number means right/bottom
     */
    translate: {
        type: PropType<number[]>;
        default: () => number[];
    };
    /**
     * 形成虚线的 实线段与间隙的长度。以线宽为单位
     * The length of the solid line segments and gaps that form the dashed line. In units of line width
     */
    dashArray: PropType<number[]>;
    offset: {
        type: NumberConstructor;
        default: number;
    };
    blur: {
        type: NumberConstructor;
        default: number;
    };
    id: {
        type: StringConstructor;
        default: () => string;
    };
    beforeId: StringConstructor;
    maxzoom: {
        type: NumberConstructor;
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    sourceId: StringConstructor;
    sourceLayerName: StringConstructor;
    geoJsonDataSource: PropType<string | import("mapbox-gl").GeoJSONSource>;
    data: PropType<import("../..").VectorLayerData | import("../..").SymbolLayerData>;
    pickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    useExpression: BooleanConstructor;
    bufferSize: {
        type: NumberConstructor;
        default: number;
    };
    generateId: BooleanConstructor;
    autoHighlight: BooleanConstructor;
    highlightColor: {
        type: PropType<string | number[]>;
        default: () => number[];
    };
    cluster: BooleanConstructor;
    clusterRadius: NumberConstructor;
    clusterMinPoints: NumberConstructor;
    clusterMaxZoom: NumberConstructor;
};
export type PolylineLayerProps = ExtractPropTypes<typeof polylineLayerProps>;
export declare const polylineLayerEmits: {
    created: () => boolean;
    click: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mousemove: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mouseleave: (event: import("mapbox-gl").MapMouseEvent) => boolean;
};
export type PolylineLayerEmits = typeof polylineLayerEmits;
export type PolylineLayerInstance = InstanceType<typeof PolylineLayer>;
