import type { ExtractPropTypes, PropType } from 'vue';
import type { IndexAny } from '@mapbox-vue3/core/es/common';
import type SymbolLayer from './symbol-layer.vue';
export declare const symbolLayerProps: {
    symbolPlacement: {
        type: StringConstructor;
        default: string;
    };
    symbolSpacing: {
        type: NumberConstructor;
        default: number;
    };
    symbolAvoidEdges: {
        type: BooleanConstructor;
        default: boolean;
    };
    symbolZOrder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 是否允许重叠
     * Whether to allow overlap
     */
    iconAllowOverlap: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 锚点位置 Anchor position
     * @values 'center', 'left', 'right', 'top', 'bottom', 'top-left', 'top-right', 'bottom-left', 'bottom-right'
     */
    iconAnchor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 图标颜色，仅在sdf icons生效
     * Icon color, only valid for sdf icons
     */
    iconColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * icon资源，预加载好的图片名
     * Icon resource, preloaded image name
     */
    iconImage: {
        type: PropType<string | any[]>;
    };
    /**
     * icon图片字段名，将从dataSource properties中读取 覆盖iconImage属性
     * The icon image field name will be read from the dataSource properties to overwrite the iconImage property
     */
    iconImageField: {
        type: StringConstructor;
    };
    /**
     * 图标放大倍数
     * Icon magnification
     */
    iconSize: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * icon与其锚点的距离 正向为右/下
     * The distance between the icon and its anchor point is right/bottom in the positive direction
     */
    iconOffset: {
        type: PropType<number[]>;
        default: () => number[];
    };
    iconOpacity: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 若为true，则icon与其他icon产生碰撞但Text未碰撞时，将只显示text
     * If true, when the icon collides with other icons but the text does not collide, only the text will be displayed
     */
    iconOptional: {
        type: BooleanConstructor;
        default: boolean;
    };
    iconRotate: {
        type: PropType<number | any[]>;
        default: number;
    };
    iconRotationAlignment: {
        type: StringConstructor;
        default: string;
    };
    iconIgnorePlacement: BooleanConstructor;
    /**
     * 锚点平移量，正方向为右/下
     * Anchor point translation, positive direction is right/down
     */
    iconTranslate: {
        type: PropType<number[]>;
        default: () => number[];
    };
    /**
     * 是否允许重叠
     * Whether to allow text overlap
     */
    textAllowOverlap: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 锚定位置 Anchor position
     * @values 'center', 'left', 'right', 'top', 'bottom', 'top-left', 'top-right', 'bottom-left', 'bottom-right'
     */
    textAnchor: {
        type: StringConstructor;
        default: string;
    };
    textColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 文本边框颜色
     * Text border color
     */
    textHaloColor: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 文本边框宽度，像素为单位
     * Text border width, in pixels
     */
    textHaloWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 文本边框炫光效果，以像素为单位
     * Text border glare effect, in pixels
     */
    textHaloBlur: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 文本值，仅在textFiled未指定时生效
     * Text value, only valid when textField is not specified
     */
    text: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 文本字段值/键值，将从dataSource properties中取值
     * The text field value/key value will be taken from the dataSource properties
     */
    textField: {
        type: StringConstructor;
        default: string;
    };
    /**
     * 文字字体，默认是Open Sans SemiBold
     * Text font, the default is Open Sans SemiBold
     */
    textFont: {
        type: PropType<string[]>;
        default: () => string[];
    };
    /**
     * 文字间距 em为单位
     * Text spacing in em units
     */
    textLetterSpacing: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * em为单位
     * em is the unit
     */
    textLineHeight: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * em为单位
     * em is the unit
     */
    textMaxWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * text与其锚点的距离 正向为右/下 px
     * The distance between the text and its anchor point (right/bottom) in the positive direction (px)
     */
    textOffset: {
        type: PropType<number[]>;
        default: () => number[];
    };
    textOpacity: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 若为true，则text与其他text产生碰撞但icon未碰撞时，将只显示icon
     * If true, when text collides with other text but not the icon, only the icon will be displayed.
     */
    textOptional: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 文本字号大小，单位px
     * Text font size, in px
     */
    textSize: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 锚点平移量，正方向为右/下 px
     * Anchor point translation, positive direction is right/down px
     */
    textTranslate: {
        type: PropType<number[]>;
        default: () => number[];
    };
    textTranslateAnchor: {
        type: StringConstructor;
        default: string;
    };
    textPadding: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 是否聚合
     * Whether to cluster
     */
    cluster: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 聚合半径
     * Cluster Radius
     */
    clusterRadius: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 聚合效果可用的最大缩放级别
     * The maximum zoom level at which the cluster effect is available
     */
    clusterMaxZoom: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 聚合效果最小聚合点数
     * Minimum cluster points for cluster effect
     */
    clusterMinPoints: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 聚合图层图标配置信息
     * cluster layer icon configuration information
     */
    clusterIcons: {
        type: PropType<IndexAny[]>;
        default: () => ({
            count: number;
            textColor: string;
            textSize: number;
            functionName: string;
            functionProps: {
                color: string;
                radius: number;
            };
        } | {
            textColor: string;
            textSize: number;
            functionName: string;
            functionProps: {
                radius: number;
                color: string;
            };
            count?: undefined;
        })[];
    };
    clusterIconSize: {
        type: NumberConstructor;
        default: number;
    };
    clusterIconTranslate: {
        type: PropType<number[]>;
        default: () => number[];
    };
    clusterIconOffset: {
        type: PropType<number[]>;
        default: () => number[];
    };
    clusterIconAnchor: {
        type: StringConstructor;
        default: string;
    };
    spiderify: {
        type: BooleanConstructor;
        default: boolean;
    };
    maxLeafesTospiderify: {
        type: NumberConstructor;
        default: number;
    };
    distanceBetweenSpiderPoints: {
        type: NumberConstructor;
        default: number;
    };
    spiderLegColor: {
        type: StringConstructor;
        default: string;
    };
    spiderLegWidth: {
        type: NumberConstructor;
        default: number;
    };
    comparePrecision: {
        type: NumberConstructor;
        default: number;
    };
    clusterSpiralPoints: {
        type: NumberConstructor;
        default: number;
    };
    id: {
        type: StringConstructor;
        default: () => string;
    };
    beforeId: StringConstructor;
    maxzoom: {
        type: NumberConstructor;
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    sourceId: StringConstructor;
    sourceLayerName: StringConstructor;
    geoJsonDataSource: PropType<string | import("mapbox-gl").GeoJSONSource>;
    data: PropType<import("../..").VectorLayerData | import("../..").SymbolLayerData>;
    pickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    useExpression: BooleanConstructor;
    bufferSize: {
        type: NumberConstructor;
        default: number;
    };
    generateId: BooleanConstructor;
    autoHighlight: BooleanConstructor;
    highlightColor: {
        type: PropType<string | number[]>;
        default: () => number[];
    };
};
export type SymbolLayerProps = ExtractPropTypes<typeof symbolLayerProps>;
export declare const symbolLayerEmits: {
    clusterclick: ({ pixel, mouseCoordinates, originalEvent, data, }: {
        pixel: number[];
        mouseCoordinates: number[];
        data: Array<{
            coordinates: number[];
            properties: IndexAny;
        }>;
        originalEvent: MouseEvent;
    }) => boolean;
    mouseenter: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: IndexAny | null;
        originalEvent: MouseEvent;
    }) => boolean;
    created: () => boolean;
    click: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mousemove: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean; /**
     * 锚点平移量，正方向为右/下
     * Anchor point translation, positive direction is right/down
     */
    mouseleave: (event: import("mapbox-gl").MapMouseEvent) => boolean;
};
export type SymbolLayerEmits = typeof symbolLayerEmits;
export type SymbolLayerInstance = InstanceType<typeof SymbolLayer>;
