import { vectorLayerProps as o, vectorLayerEmits as l } from "../../vector-layer/src/vector-layer.mjs";
const u = {
  ...o,
  symbolPlacement: {
    type: String,
    default: "point"
    // 'point','line','line-center'
  },
  symbolSpacing: {
    type: Number,
    default: 250
  },
  symbolAvoidEdges: {
    type: Boolean,
    default: !1
  },
  symbolZOrder: {
    type: String,
    default: "auto"
  },
  /**
   * 是否允许重叠
   * Whether to allow overlap
   */
  iconAllowOverlap: {
    type: Boolean,
    default: !1
  },
  /**
   * 锚点位置 Anchor position
   * @values 'center', 'left', 'right', 'top', 'bottom', 'top-left', 'top-right', 'bottom-left', 'bottom-right'
   */
  iconAnchor: {
    type: String,
    default: "center"
  },
  /**
   * 图标颜色，仅在sdf icons生效
   * Icon color, only valid for sdf icons
   */
  iconColor: {
    type: String,
    default: "#000000"
  },
  /**
   * icon资源，预加载好的图片名
   * Icon resource, preloaded image name
   */
  iconImage: {
    type: [String, Array]
  },
  /**
   * icon图片字段名，将从dataSource properties中读取 覆盖iconImage属性
   * The icon image field name will be read from the dataSource properties to overwrite the iconImage property
   */
  iconImageField: {
    type: String
  },
  /**
   * 图标放大倍数
   * Icon magnification
   */
  iconSize: {
    type: Number,
    default: 1
  },
  /**
   * icon与其锚点的距离 正向为右/下
   * The distance between the icon and its anchor point is right/bottom in the positive direction
   */
  iconOffset: {
    type: Array,
    default: () => [0, 0]
  },
  iconOpacity: {
    type: Number,
    default: 1
  },
  /**
   * 若为true，则icon与其他icon产生碰撞但Text未碰撞时，将只显示text
   * If true, when the icon collides with other icons but the text does not collide, only the text will be displayed
   */
  iconOptional: {
    type: Boolean,
    default: !1
  },
  iconRotate: {
    type: [Number, Array],
    default: 0
  },
  iconRotationAlignment: {
    type: String,
    default: "auto"
  },
  iconIgnorePlacement: Boolean,
  /**
   * 锚点平移量，正方向为右/下
   * Anchor point translation, positive direction is right/down
   */
  iconTranslate: {
    type: Array,
    default: () => [0, 0]
  },
  /**
   * 是否允许重叠
   * Whether to allow text overlap
   */
  textAllowOverlap: {
    type: Boolean,
    default: !1
  },
  /**
   * 锚定位置 Anchor position
   * @values 'center', 'left', 'right', 'top', 'bottom', 'top-left', 'top-right', 'bottom-left', 'bottom-right'
   */
  textAnchor: {
    type: String,
    default: "center"
  },
  textColor: {
    type: String,
    default: "#000000"
  },
  /**
   * 文本边框颜色
   * Text border color
   */
  textHaloColor: {
    type: String,
    default: "rgba(0, 0, 0, 0)"
  },
  /**
   * 文本边框宽度，像素为单位
   * Text border width, in pixels
   */
  textHaloWidth: {
    type: Number,
    default: 0
  },
  /**
   * 文本边框炫光效果，以像素为单位
   * Text border glare effect, in pixels
   */
  textHaloBlur: {
    type: Number,
    default: 0
  },
  /**
   * 文本值，仅在textFiled未指定时生效
   * Text value, only valid when textField is not specified
   */
  text: {
    type: String,
    default: ""
  },
  /**
   * 文本字段值/键值，将从dataSource properties中取值
   * The text field value/key value will be taken from the dataSource properties
   */
  textField: {
    type: String,
    default: ""
  },
  /**
   * 文字字体，默认是Open Sans SemiBold
   * Text font, the default is Open Sans SemiBold
   */
  textFont: {
    type: Array,
    default: () => ["Open Sans SemiBold"]
  },
  /**
   * 文字间距 em为单位
   * Text spacing in em units
   */
  textLetterSpacing: {
    type: Number,
    default: 0
  },
  /**
   * em为单位
   * em is the unit
   */
  textLineHeight: {
    type: Number,
    default: 1.2
  },
  /**
   * em为单位
   * em is the unit
   */
  textMaxWidth: {
    type: Number,
    default: 10
  },
  /**
   * text与其锚点的距离 正向为右/下 px
   * The distance between the text and its anchor point (right/bottom) in the positive direction (px)
   */
  textOffset: {
    type: Array,
    default: () => [0, 0]
  },
  textOpacity: {
    type: Number,
    default: 1
  },
  /**
   * 若为true，则text与其他text产生碰撞但icon未碰撞时，将只显示icon
   * If true, when text collides with other text but not the icon, only the icon will be displayed.
   */
  textOptional: {
    type: Boolean,
    default: !1
  },
  /**
   * 文本字号大小，单位px
   * Text font size, in px
   */
  textSize: {
    type: Number,
    default: 16
  },
  /**
   * 锚点平移量，正方向为右/下 px
   * Anchor point translation, positive direction is right/down px
   */
  textTranslate: {
    type: Array,
    default: () => [0, 0]
  },
  textTranslateAnchor: {
    type: String,
    default: "viewport"
  },
  textPadding: {
    type: Number,
    default: 2
  },
  /**
   * 是否聚合
   * Whether to cluster
   */
  cluster: {
    type: Boolean,
    default: !1
  },
  /**
   * 聚合半径
   * Cluster Radius
   */
  clusterRadius: {
    type: Number,
    default: 50
  },
  /**
   * 聚合效果可用的最大缩放级别
   * The maximum zoom level at which the cluster effect is available
   */
  clusterMaxZoom: {
    type: Number,
    default: 22
  },
  /**
   * 聚合效果最小聚合点数
   * Minimum cluster points for cluster effect
   */
  clusterMinPoints: {
    type: Number,
    default: 2
  },
  /**
   * 聚合图层图标配置信息
   * cluster layer icon configuration information
   */
  clusterIcons: {
    type: Array,
    default: () => [
      {
        count: 50,
        textColor: "black",
        textSize: 12,
        functionName: "drawDynamicCircle",
        functionProps: {
          color: "#68B8EE",
          radius: 50
        }
      },
      {
        count: 100,
        textColor: "black",
        textSize: 14,
        functionName: "drawDynamicCircle",
        functionProps: {
          color: "#B1E345",
          radius: 75
        }
      },
      {
        count: 200,
        textColor: "white",
        textSize: 18,
        functionName: "drawDynamicCircle",
        functionProps: {
          color: "#F7DC00",
          radius: 100
        }
      },
      {
        count: 500,
        textColor: "white",
        textSize: 20,
        functionName: "drawDynamicCircle",
        functionProps: {
          color: "#FA9800",
          radius: 125
        }
      },
      {
        textColor: "white",
        textSize: 22,
        functionName: "drawDynamicCircle",
        functionProps: {
          radius: 150,
          color: "#F34A4A"
        }
      }
    ]
  },
  clusterIconSize: {
    type: Number,
    default: 1
  },
  clusterIconTranslate: {
    type: Array,
    default: () => [0, 0]
  },
  clusterIconOffset: {
    type: Array,
    default: () => [0, 0]
  },
  clusterIconAnchor: {
    type: String,
    default: "center"
  },
  spiderify: {
    type: Boolean,
    default: !1
  },
  maxLeafesTospiderify: {
    type: Number,
    default: 50
  },
  distanceBetweenSpiderPoints: {
    type: Number,
    default: 50
  },
  spiderLegColor: {
    type: String,
    default: "#B6CBED"
  },
  spiderLegWidth: {
    type: Number,
    default: 3
  },
  comparePrecision: {
    type: Number,
    default: 5
  },
  clusterSpiralPoints: {
    type: Number,
    default: 10
  }
}, y = {
  ...l,
  clusterclick: ({
    pixel: e,
    mouseCoordinates: t,
    originalEvent: r,
    data: a
  }) => Array.isArray(e) && Array.isArray(t) && Array.isArray(a),
  mouseenter: ({
    pixel: e,
    mouseCoordinates: t,
    coordinates: r,
    properties: a,
    originalEvent: i
  }) => Array.isArray(e) && Array.isArray(t) && Array.isArray(r)
};
export {
  y as symbolLayerEmits,
  u as symbolLayerProps
};
