import type { ExtractPropTypes, PropType } from 'vue';
import type UrlTemplateLayer from './url-template-layer.vue';
export declare const urlTemplateLayerProps: {
    /**
     * 用来访问切片的url,有如下关键字：
     * {z}:切片级别
     * {y}：y轴瓦片号
     * {x}：x轴瓦片号
     * {s}：可用域名
     */
    /**
     * The URL used to access the slice, with the following keywords:
     * {z}: slice level
     * {y}: y-axis tile number
     * {x}: x-axis tile number
     * {s}: available domain name
     */
    url: {
        type: StringConstructor;
        required: boolean;
    };
    subdomains: PropType<string | number[] | string[]>;
    /**
     * 数据源切片方案
     * Data source tiling scheme
     * @values 'xyz','tms'
     */
    scheme: {
        type: StringConstructor;
        default: string;
        validator: (val: string) => boolean;
    };
    maxzoom: {
        type: NumberConstructor;
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    beforeId: {
        type: StringConstructor;
    };
    id: {
        type: StringConstructor;
        default: () => string;
    };
    extendSource: {
        type: ObjectConstructor;
        default: () => {};
    };
};
export type UrlTemplateLayerProps = ExtractPropTypes<typeof urlTemplateLayerProps>;
export declare const urlTemplateLayerEmits: {
    created: () => boolean;
};
export type UrlTemplateLayerEmits = typeof urlTemplateLayerEmits;
export type UrlTemplateLayerInstance = InstanceType<typeof UrlTemplateLayer>;
