import type { ExtractPropTypes, PropType } from 'vue';
import type CircleLayer from './circle-layer.vue';
export declare const circleLayerProps: {
    /**
     * 圆半径，可设为数字或数组
     * ['mag',1,5,14,20]表示依据mag属性值来设置圆半径，值为1/14时圆半径为5/20
     * [1,5,14,20]表示地图zoom值为1/14时圆半径为5/20
     */
    /**
     * Circle radius, can be set to a number or array
     * ['mag',1,5,14,20] means setting the circle radius based on the mag attribute value. When the value is 1/14, the circle radius is 5/20
     * [1,5,14,20] means when the map zoom value is 1/14, the circle radius is 5/20
     */
    radius: {
        type: PropType<number | (string | number)[]>;
        default: number;
    };
    /**
     * 圆模糊量，值为1时只有圆中心点是不透明状态
     * The amount of circular blur. When the value is 1, only the center of the circle is opaque.
     */
    blur: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 颜色值
     * 可设为数字或数组
     * ['mag',1,'rgba(33,102,172,0)',14,'rgb(253,219,199)']表示依据mag属性值来设置颜色值，值为1/14时颜色值为rgba(33,102,172,0)/rgb(253,219,199)
     */
    /**
     * Color value
     * Can be set to a number or array
     * ['mag',1,'rgba(33,102,172,0)',14,'rgb(253,219,199)'] means setting the color value according to the mag attribute value. When the value is 1/14, the color value is rgba(33,102,172,0)/rgb(253,219,199)
     */
    color: {
        type: PropType<number | (string | number)[]>;
        default: string;
    };
    /**
     * 透明度，默认值为1
     * 若设置为数组，则与zoom关联
     * 例如：[7,1,9,0]表示0~7级透明度为1，9以上透明度为0
     */
    /**
     * opacity, default value is 1
     * If set to an array, it is associated with zoom
     * For example: [7,1,9,0] means that the opacity level 0 to 7 is 1, and the opacity level above 9 is 0
     */
    opacity: {
        type: PropType<number | number[]>;
        default: number;
    };
    /**
     * 锚点平移量，正方向为右/下 px
     * Anchor point translation, positive direction is right/down px
     */
    translate: {
        type: PropType<number[]>;
        default: () => number[];
    };
    /**
     * 圆边框宽度，单位px
     * Circle border width, in px
     */
    strokeWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 圆边框颜色
     * 可设为数字或数组
     * ['mag',1,'rgba(33,102,172,0)',14,'rgb(253,219,199)']表示依据mag属性值来设置颜色值，值为1/14时颜色值为rgba(33,102,172,0)/rgb(253,219,199)
     */
    /**
     * Circle border color
     * Can be set to a number or array
     * ['mag',1,'rgba(33,102,172,0)',14,'rgb(253,219,199)'] means setting the color value according to the mag attribute value. When the value is 1/14, the color value is rgba(33,102,172,0)/rgb(253,219,199)
     */
    strokeColor: {
        type: PropType<string | (string | number)[]>;
        default: string;
    };
    /**
     * 圆边框透明度
     * Circle border opacity
     */
    strokeOpacity: {
        type: PropType<number | (string | number)[]>;
        default: number;
    };
    id: {
        type: StringConstructor;
        default: () => string;
    };
    beforeId: StringConstructor;
    maxzoom: {
        type: NumberConstructor;
        /**
         * Circle radius, can be set to a number or array
         * ['mag',1,5,14,20] means setting the circle radius based on the mag attribute value. When the value is 1/14, the circle radius is 5/20
         * [1,5,14,20] means when the map zoom value is 1/14, the circle radius is 5/20
         */
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    sourceId: StringConstructor;
    sourceLayerName: StringConstructor;
    geoJsonDataSource: PropType<string | import("mapbox-gl").GeoJSONSource>;
    data: PropType<import("../..").VectorLayerData | import("../..").SymbolLayerData>;
    pickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    useExpression: BooleanConstructor;
    bufferSize: {
        type: NumberConstructor;
        default: number;
    };
    generateId: BooleanConstructor;
    autoHighlight: BooleanConstructor;
    highlightColor: {
        type: PropType<string | number[]>;
        default: () => number[];
    };
    cluster: BooleanConstructor;
    clusterRadius: NumberConstructor;
    clusterMinPoints: NumberConstructor;
    clusterMaxZoom: NumberConstructor;
};
export type CircleLayerProps = ExtractPropTypes<typeof circleLayerProps>;
export declare const circleLayerEmits: {
    created: () => boolean;
    click: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mousemove: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mouseleave: (event: import("mapbox-gl").MapMouseEvent) => boolean;
};
export type CircleLayerEmits = typeof circleLayerEmits;
export type CircleLayerInstance = InstanceType<typeof CircleLayer>;
