import type { AxiosResponse } from 'axios';
declare const TiandituApi: {
    token: string;
    baseUrl: string;
    urls: {
        geocoder: string;
        search: string;
        pathByDrive: string;
        pathByMass: string;
    };
    locationToAddress(longitude: string | number, latitude: string | number, token?: string): Promise<AxiosResponse<AxiosResponse<LocationToAddress.Model, any>, any>>;
    addressToLocation(keyword: string, token?: string): Promise<AxiosResponse<AxiosResponse<AddressToLocation.Model, any>, any>>;
    searchAddressByKeyword(keyword: string | Record<string, any>, count?: number, area?: string, token?: string): Promise<AxiosResponse<AxiosResponse<SearchAddressList.Model, any>, any>>;
    pathGeneratorByCar({ orig, dest, mid, style, }: {
        orig: string;
        dest: string;
        mid: string;
        style: number;
    }, token?: string): Promise<AxiosResponse<AxiosResponse<XMLDocument, any>, any>>;
    pathGeneratorByMass({ startPosition, endPosition, lineType, }: {
        startPosition: string;
        endPosition: string;
        lineType: string;
    }, token?: string): Promise<AxiosResponse<AxiosResponse<XMLDocument, any>, any>>;
};
export interface TiandituApiModel<T> {
    result: T;
    msg: string;
    status: string;
}
export declare namespace AddressToLocation {
    interface Location {
        lon: string;
        lat: string;
        level: string;
    }
    export type Model = {
        location: Location;
        status: string;
        msg: string;
        serchVersion: string;
    };
    export {};
}
export declare namespace LocationToAddress {
    interface Location {
        lon: number;
        lat: number;
    }
    interface AddressComponent {
        address: string;
        city: string;
        road: string;
        poi_position: string;
        address_position: string;
        road_distance: number;
        poi: string;
        poi_distance: string;
        address_distance: number;
    }
    export interface Result {
        formatted_address: string;
        location: Location;
        addressComponent: AddressComponent;
    }
    export type Model = TiandituApiModel<Result>;
    export {};
}
export declare namespace SearchAddressList {
    interface StationData {
        lineName: string;
        uuid: string;
        stationUuid: string;
    }
    interface Pois {
        name: string;
        phone: string;
        address: string;
        lonlat: string;
        poiType: number;
        eaddress: string;
        ename: string;
        hotPointID: string;
        province: string;
        provinceCode: string;
        city: string;
        cityCode: string;
        county: string;
        countyCode: string;
        source: string;
        typeCode: string;
        typeName: string;
        stationData: StationData;
    }
    interface Prompt {
        type: number;
        admins: [
            {
                adminName: string;
                adminCode: string;
            }
        ];
    }
    interface PriorityCitys {
        name: string;
        count: number;
        lonlat: string;
        ename: string;
        adminCode: number;
    }
    interface AllAdmins {
        name: string;
        count: number;
        lonlat: string;
        ename: string;
        adminCode: number;
        isleaf: boolean;
    }
    interface Statistics {
        count: number;
        adminCount: number;
        priorityCitys: PriorityCitys[];
        allAdmins: AllAdmins[];
    }
    interface Area {
        name: string;
        bound: string;
        lonlat: string;
        adminCode: number;
        level: number;
    }
    interface LineData {
        stationNum: string;
        poiType: string;
        name: string;
        uuid: string;
    }
    interface Status {
        infocode: number;
        cndesc: string;
    }
    export type Model = {
        resultType: number;
        count: number;
        keyword: string;
        pois: Pois[];
        prompt: Prompt;
        statistics: Statistics;
        area: Area[];
        lineData: LineData[];
        status: Status[];
    };
    export {};
}
export { TiandituApi };
