import type { ExtractPropTypes, PropType } from 'vue';
import type TiandituLayer from './tianditu-layer.vue';
/**
 * 天地图图层，支持天地图图所有瓦片服务 无偏
 * Tiandi map layer, supports all tile services of Tiandi map, unbiased
 * @see [矢量底图vec ](http://t0.tianditu.gov.cn/vec_w/wmts?tk=82d822a61cefc9898e63a0c51e933f5a&layer=cva&style=default&tilematrixset=w&Service=WMTS&Request=GetCapabilities)
 * @see [矢量注记cva ](http://t0.tianditu.gov.cn/cva_w/wmts?tk=82d822a61cefc9898e63a0c51e933f5a&layer=cva&style=default&tilematrixset=w&Service=WMTS&Request=GetCapabilities)
 * @see [影像底图img ](http://t0.tianditu.gov.cn/img_w/wmts?tk=82d822a61cefc9898e63a0c51e933f5a&layer=cva&style=default&tilematrixset=w&Service=WMTS&Request=GetCapabilities)
 * @see [影像注记cia ](http://t0.tianditu.gov.cn/cia_w/wmts?tk=82d822a61cefc9898e63a0c51e933f5a&layer=cva&style=default&tilematrixset=w&Service=WMTS&Request=GetCapabilities)
 * @see [地形晕渲ter ](http://t0.tianditu.gov.cn/ter_w/wmts?tk=82d822a61cefc9898e63a0c51e933f5a&layer=cva&style=default&tilematrixset=w&Service=WMTS&Request=GetCapabilities)
 * @see [地形注记cta ](http://t0.tianditu.gov.cn/cta_w/wmts?tk=82d822a61cefc9898e63a0c51e933f5a&layer=cva&style=default&tilematrixset=w&Service=WMTS&Request=GetCapabilities)
 * @author cilc
 **/
export declare const tiandituLayerProps: {
    /**
     * 矢量底图:'vec' 矢量注记:'cva' 影像底图:'img' 影像注记:'cia' 地形晕渲:'ter' 地形注记'cta'
     * Vector basemap: 'vec' Vector annotation: 'cva' Image basemap: 'img' Image annotation: 'cia' Terrain shading: 'ter' Terrain annotation 'cta'
     */
    types: {
        type: PropType<("img" | "vec" | "cva" | "cia" | "ter" | "cta")[]>;
        default: () => string[];
    };
    token: {
        type: StringConstructor;
        default: string;
    };
    maxzoom: {
        type: NumberConstructor;
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    beforeId: StringConstructor;
    id: {
        type: StringConstructor;
        default: () => string;
    };
};
export type TiandituLayerProps = ExtractPropTypes<typeof tiandituLayerProps>;
export declare const tiandituLayerEmits: {
    created: () => boolean;
};
export type TiandituLayerEmits = typeof tiandituLayerEmits;
export type TiandituLayerInstance = InstanceType<typeof TiandituLayer>;
