import type { ExtractPropTypes, PropType } from 'vue';
import type { GeoJSONSource, MapMouseEvent } from 'mapbox-gl';
import type { SymbolLayerData, VectorLayerData } from '@mapbox-vue3/core/es/map';
export declare const vectorLayerProps: {
    id: {
        type: StringConstructor;
        default: () => string;
    };
    beforeId: StringConstructor;
    maxzoom: {
        type: NumberConstructor;
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    sourceId: StringConstructor;
    sourceLayerName: StringConstructor;
    geoJsonDataSource: PropType<string | GeoJSONSource>;
    /**
     * 矢量图层的数据
     * 数组中每个对象需包含必需的coordinates属性以及可选的properties属性
     * 每一个对象代表一个点/一条线/一个多边形
     */
    /**
     * Vector layer data
     * Each object in the array must contain the required coordinates attribute and the optional properties attribute
     * Each object represents a point/line/polygon
     */
    data: PropType<VectorLayerData | SymbolLayerData>;
    pickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    useExpression: BooleanConstructor;
    bufferSize: {
        type: NumberConstructor;
        default: number;
    };
    generateId: BooleanConstructor;
    autoHighlight: BooleanConstructor;
    highlightColor: {
        type: PropType<string | number[]>;
        default: () => number[];
    };
    cluster: BooleanConstructor;
    clusterRadius: NumberConstructor;
    clusterMinPoints: NumberConstructor;
    clusterMaxZoom: NumberConstructor;
};
export type VectorLayerProps = ExtractPropTypes<typeof vectorLayerProps>;
export declare const vectorLayerEmits: {
    created: () => boolean;
    click: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mousemove: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mouseleave: (event: MapMouseEvent) => boolean;
};
export type VectorLayerEmits = typeof vectorLayerEmits;
